.. include:: ../README.rst


.. toctree::
   :hidden:
   :caption: User Guides

   getting_started

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Examples

   generated/autoexamples/index


.. toctree::
   :hidden:
   :caption: API References

   api

.. toctree::
   :hidden:
   :caption: Miscellaneous

   misc/contributors
   misc/code_of_conduct
   misc/license
   misc/development

.. toctree::
   :hidden:
   :caption: Related Projects

   Brainweb-dl <http://github.com/paquiteau/brainweb-dl>
   Phantominator <https://github.com/mckib2/phantominator>
   SigPy <https://github.com/mikgroup/sigpy>
